==> nextcloud-24.0.9.tgz: nextcloud/apps/dashboard/l10n/pt_BR.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Painel",
    "Dashboard app" : "Aplicativo Painel",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Comece o seu dia informado\n\nO Painel Nextcloud é o seu ponto de partida do dia, dando-lhe uma\nvisão geral de seus compromissos futuros, e-mails urgentes, mensagens de bate-papo,\ningressos recebidos, tweets mais recentes e muito mais! Os usuários podem adicionar os widgets\neles gostam e mudam o fundo ao seu gosto.",
    "Customize" : "Personalizar",
    "Edit widgets" : "Editar widgets",
    "Get more widgets from the App Store" : "Obtenha mais widgets na App Store",
    "Weather service" : "Serviço de Clima",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Para sua privacidade, as informações de Tempo são solicitadas pelo servidor Nextcloud de forma que o serviço de Tempo não receba suas informações pessoais.",
    "Weather data from Met.no" : "Dados de Tempo do Met.no",
    "geocoding with Nominatim" : "geocodificado com Nominatim",
    "elevation data from OpenTopoData" : "dados topográficos de OpenTopoData",
    "Weather" : "Clima",
    "Status" : "Status",
    "Good morning" : "Bom dia",
    "Good morning, {name}" : "Bom dia, {name}",
    "Good afternoon" : "Boa tarde",
    "Good afternoon, {name}" : "Boa tarde, {name}",
    "Good evening" : "Boa noite",
    "Good evening, {name}" : "Boa noite, {name}",
    "Hello" : "Olá",
    "Hello, {name}" : "Olá, {name}",
    "Change background image" : "Mudar imagem de fundo",
    "Pick from Files" : "Escolher de Arquivos",
    "Default images" : "Imagens padrão",
    "Plain background" : "Fundo simples",
    "Insert from {productName}" : "Inserir de {productName}"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-25.0.6.tgz: nextcloud/apps/dashboard/l10n/pt_BR.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Painel",
    "Dashboard app" : "Aplicativo Painel",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking.",
    "\"{title} icon\"" : "\"{title} icon\"",
    "Customize" : "Personalizar",
    "Edit widgets" : "Editar widgets",
    "Get more widgets from the App Store" : "Obtenha mais widgets na App Store",
    "Weather service" : "Serviço de Clima",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Para sua privacidade, as informações de Tempo são solicitadas pelo servidor Nextcloud de forma que o serviço de Tempo não receba suas informações pessoais.",
    "Weather data from Met.no" : "Dados de Tempo do Met.no",
    "geocoding with Nominatim" : "geocodificado com Nominatim",
    "elevation data from OpenTopoData" : "dados topográficos de OpenTopoData",
    "Weather" : "Clima",
    "Status" : "Status",
    "Good morning" : "Bom dia",
    "Good morning, {name}" : "Bom dia, {name}",
    "Good afternoon" : "Boa tarde",
    "Good afternoon, {name}" : "Boa tarde, {name}",
    "Good evening" : "Boa noite",
    "Good evening, {name}" : "Boa noite, {name}",
    "Hello" : "Olá",
    "Hello, {name}" : "Olá, {name}",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Comece o seu dia informado\n\nO Painel Nextcloud é o seu ponto de partida do dia, dando-lhe uma\nvisão geral de seus compromissos futuros, e-mails urgentes, mensagens de bate-papo,\ningressos recebidos, tweets mais recentes e muito mais! Os usuários podem adicionar os widgets\neles gostam e mudam o fundo ao seu gosto.",
    "Change background image" : "Mudar imagem de fundo",
    "Pick from Files" : "Escolher de Arquivos",
    "Default images" : "Imagens padrão",
    "Plain background" : "Fundo simples",
    "Insert from {productName}" : "Inserir de {productName}"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
